--[[-----------------------------------------------------------------------------
ItemInfo Widget
Displays an item icon with name, Reforging, and equipment slot info
-------------------------------------------------------------------------------]]
local Type, Version = "PlayerUpgradeViewHeader", 1
local AceGUI = LibStub and LibStub("AceGUI-3.0", true)
if not AceGUI or (AceGUI:GetWidgetVersion(Type) or 0) >= Version then return end

-- Lua APIs
local max, select, pairs = math.max, select, pairs

-- WoW APIs
local CreateFrame, UIParent = CreateFrame, UIParent

-- Global vars/functions that we don't upvalue since they might get hooked, or upgraded
-- List them here for Mikk's FindGlobals script
-- GLOBALS: GameFontHighlightSmall

--[[-----------------------------------------------------------------------------
Methods
-------------------------------------------------------------------------------]]
local methods = {
	["OnAcquire"] = function(self)
	end,
	
	["SetText"] = function(self, equippedItemText, droppedItemText, playerText, nameText, scoreText, upgradeText)
		self.equippedItem:SetText(equippedItemText)
		self.droppedItem:SetText(droppedItemText)
		self.player:SetText(playerText)
		self.name:SetText(nameText)
		self.equippedItemScore:SetText(scoreText)
		self.droppedItemScore:SetText(scoreText)
		self.pctUpgrade:SetText(upgradeText)
	end
}
--[[-----------------------------------------------------------------------------
Constructor
-------------------------------------------------------------------------------]]
local PaneBackdrop  = {
	bgFile = "Interface\\ChatFrame\\ChatFrameBackground",
	edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border",
	tile = true, tileSize = 16, edgeSize = 16,
	insets = { left = 5, right = 3, top = 3, bottom = 5 }
}


local function Constructor()
	local playerWidth = 124
	local nameWidth = 195
	local scoreWidth = 62
	local upgradeWidth = 69

	local frame = CreateFrame("Frame", nil, UIParent)
	frame:SetFrameStrata("FULLSCREEN_DIALOG")
	frame:SetWidth(526)
	frame:SetBackdrop(PaneBackdrop)
	frame:SetBackdropColor(0.1, 0.1, 0.1, 0.5)
	frame:SetBackdropBorderColor(0.4, 0.4, 0.4)

	local equippedItem = frame:CreateFontString(nil, nil, "GameFontHighlightSmall")
	equippedItem:SetJustifyH("LEFT")
	equippedItem:SetFont("Fonts\\FRIZQT__.TTF", 14)
	equippedItem:SetTextColor(YELLOW_FONT_COLOR.r, YELLOW_FONT_COLOR.g, YELLOW_FONT_COLOR.b)
	equippedItem:SetText("Equipped Item")
	equippedItem:SetPoint("TOPLEFT", frame, "TOPLEFT", playerWidth + 7, -7)
	
	local droppedItem = frame:CreateFontString(nil, nil, "GameFontHighlightSmall")
	droppedItem:SetJustifyH("LEFT")
	droppedItem:SetFont("Fonts\\FRIZQT__.TTF", 14)
	droppedItem:SetTextColor(YELLOW_FONT_COLOR.r, YELLOW_FONT_COLOR.g, YELLOW_FONT_COLOR.b)
	droppedItem:SetText("Dropped Item")
	droppedItem:SetPoint("TOPRIGHT", frame, "TOPRIGHT", -7, -7)
	droppedItem:SetPoint("LEFT", frame, "RIGHT", 0 - scoreWidth - upgradeWidth, 0)		
	droppedItem:SetPoint("BOTTOM", equippedItem)		
	equippedItem:SetPoint("RIGHT", frame, "RIGHT", 0 - upgradeWidth - scoreWidth, 0)

	local player = frame:CreateFontString(nil, nil, "GameFontHighlightSmall")
	player:SetJustifyH("LEFT")
	player:SetFont("Fonts\\FRIZQT__.TTF", 14)
	player:SetText("Player")
	player:SetPoint("TOPRIGHT", equippedItem, "BOTTOMLEFT")
	player:SetPoint("LEFT", frame, "LEFT", 7, 0)

	local name = frame:CreateFontString(nil, nil, "GameFontHighlightSmall")
	name:SetJustifyH("LEFT")
	name:SetFont("Fonts\\FRIZQT__.TTF", 14)
	name:SetText("Name")
	name:SetPoint("TOPLEFT", equippedItem, "BOTTOMLEFT")

	local equippedItemScore = frame:CreateFontString(nil, nil, "GameFontHighlightSmall")
	equippedItemScore:SetJustifyH("LEFT")
	equippedItemScore:SetFont("Fonts\\FRIZQT__.TTF", 14)
	equippedItemScore:SetText("Score")
	equippedItemScore:SetPoint("LEFT", equippedItem, "RIGHT", 0 - scoreWidth, 0)
	name:SetPoint("RIGHT", equippedItemScore, "LEFT")
	equippedItemScore:SetPoint("TOPRIGHT", equippedItem, "BOTTOMRIGHT")

	local droppedItemScore = frame:CreateFontString(nil, nil, "GameFontHighlightSmall")
	droppedItemScore:SetJustifyH("LEFT")
	droppedItemScore:SetFont("Fonts\\FRIZQT__.TTF", 14)
	droppedItemScore:SetText("Score")
	droppedItemScore:SetPoint("TOPLEFT", equippedItem, "BOTTOMRIGHT")
	droppedItemScore:SetPoint("RIGHT", droppedItem, "LEFT", scoreWidth, 0)

	local pctUpgrade = frame:CreateFontString(nil, nil, "GameFontHighlightSmall")
	pctUpgrade:SetJustifyH("LEFT")
	pctUpgrade:SetFont("Fonts\\FRIZQT__.TTF", 14)
	pctUpgrade:SetText("Upgrade")
	pctUpgrade:SetPoint("TOPRIGHT", droppedItem, "BOTTOMRIGHT")
	pctUpgrade:SetPoint("LEFT", droppedItemScore, "RIGHT")
	
	frame:SetHeight(equippedItem:GetStringHeight() + equippedItemScore:GetStringHeight() + 14)

	local widget = {
		frame = frame,
		equippedItem = equippedItem,
		droppedItem = droppedItem,
		player = player,
		name = name,
		equippedItemScore = equippedItemScore,
		droppedItemScore = droppedItemScore,
		pctUpgrade = pctUpgrade
	}
	for method, func in pairs(methods) do
		widget[method] = func
	end

	return AceGUI:RegisterAsWidget(widget)
end

AceGUI:RegisterWidgetType(Type, Constructor, Version)
